@@ -36,7 +36,7 @@ our %EXPORT_TAGS = (
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT    = ( @{ $EXPORT_TAGS{'default'} } );
 
-$VERSION = '0.94';
+$VERSION = '0.96';
 
 {
   my %Checked;
@@ -337,7 +337,7 @@ sub flush {
   }
 	else {
 		msg("Flushing '$build_dir'");
-		rmtree($build_dir);
+		rmtree($build_dir) if -e $build_dir;
 		msg("Flushed '$build_dir'");
     require File::Glob;
     ( my $base = $self->{conf}->get_conf('base') ) =~ s![\\/]$!!;
